package com.datacloudsec.scan.common;

import com.datacloudsec.utils.SecretUtil;
import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.Properties;
import org.apache.commons.io.FileUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.log4j.Logger;

/* loaded from: com_datacloudsec_scan_common.jar:com/datacloudsec/scan/common/Config.class */
public class Config {
    public static final Logger LOG = Logger.getLogger(Config.class);
    public static final String CONF_USER_AGENT = "user-agent";
    public static final String CONF_PERIOD_EXEC = "periodExec";
    public static final String CONF_ENGINE_SYNC = "engineSync";
    public static final String CONF_UPDATE_ADDR = "update-addr";
    public static final String CONF_ENGINE_PASSWORD = "engine-password";
    private static Config instance;
    private Properties config;

    private Config() {
        try {
            byte[] configContent = FileUtils.readFileToByteArray(new File(Constant.WORK_DIR, "conf/config.properties"));
            this.config = new Properties();
            this.config.load(new InputStreamReader(new ByteArrayInputStream(configContent), "UTF-8"));
            byte[] configEncContent = null;
            try {
                byte[] configEncContent2 = FileUtils.readFileToByteArray(new File(Constant.WORK_DIR, "conf/config-enc.properties"));
                configEncContent = SecretUtil.decryptEncrypt("aes", configEncContent2, Constant.CONF_KEY.getBytes());
            } catch (Exception e) {
            }
            Properties configEnc = new Properties();
            configEnc.load(new InputStreamReader(new ByteArrayInputStream(configEncContent), "UTF-8"));
            this.config.putAll(configEnc);
        } catch (IOException e2) {
            LOG.error("加载配置文件出错", e2);
        }
    }

    public static Config getInstance() {
        if (instance == null) {
            instance = new Config();
        }
        return instance;
    }

    public boolean getBoolean(String key, boolean def) {
        try {
            return "true".equalsIgnoreCase(this.config.getProperty(key));
        } catch (Exception e) {
            return def;
        }
    }

    public int getInt(String key, int def) {
        try {
            return Integer.parseInt(this.config.getProperty(key));
        } catch (Exception e) {
            return def;
        }
    }

    public String getString(String key, String def) {
        String val = this.config.getProperty(key);
        if (StringUtils.isBlank(val)) {
            return def;
        }
        return val;
    }

    public Properties getConfig() {
        return this.config;
    }
}
